@@ -5,7 +5,7 @@ use Moo;
 use Catmandu::Store::DBI::Iterator;
 use namespace::clean;
 
-our $VERSION = "0.0503";
+our $VERSION = "0.0504";
 
 my $default_mapping = {
     _id => {
@@ -13,16 +13,20 @@ my $default_mapping = {
         type => 'string',
         index => 1,
         required => 1,
-        unique => 1
+        unique => 1,
     },
     _data => {
         column => 'data',
         type => 'binary',
-        serialize => 'all'
+        serialize => 'all',
     }
 };
 
-has mapping => (is => 'ro', default => sub { +{%$default_mapping} });
+has mapping => (
+    is => 'ro',
+    default => sub { +{%$default_mapping} },
+);
+
 has _iterator => (
     is => 'ro',
     lazy => 1,
@@ -34,7 +38,7 @@ has _iterator => (
         select
         detect
         first
-    )]
+    )],
 );
 
 with 'Catmandu::Bag';
@@ -43,6 +47,7 @@ with 'Catmandu::Serializer';
 sub BUILD {
     my ($self) = @_;
     $self->_normalize_mapping;
+    # TODO should happen lazily;
     $self->store->handler->create_table($self);
 }
 
@@ -126,6 +131,12 @@ sub _row_to_data {
                 next;
             }
         }
+        if ($map->{type} eq "datetime") {
+
+            my($date,$time) = split ' ', $val;
+            $val = "${date}T${time}Z";
+
+        }
         $data->{$key} = $val;
     }
 
@@ -149,6 +160,12 @@ sub _data_to_row {
             }
             $val = $self->serialize($val // next);
         }
+        if ($map->{type} eq "datetime") {
+
+            chop($val);
+            $val = join(' ',split('T',$val));
+
+        }
         $row->{$map->{column}} = $val // next;
     }
 
