@@ -5,7 +5,7 @@ use DBD::Pg ();
 use Moo;
 use namespace::clean;
 
-our $VERSION = "0.0503";
+our $VERSION = "0.0504";
 
 with 'Catmandu::Store::DBI::Handler';
 
@@ -20,6 +20,8 @@ sub _column_sql {
         $sql .= 'INTEGER';
     } elsif ($map->{type} eq 'binary') {
         $sql .= 'BYTEA';
+    } elsif ($map->{type} eq 'datetime') {
+        $sql .= 'TIMESTAMP';
     }
     if ($map->{array}) {
         $sql .= '[]';
